@@ -14,6 +14,7 @@ class Error(Exception):
         self._message = message
         self.gds_codes = gds_codes
         self.sql_code = sql_code
+        self.args = [message, sql_code]
     def __str__(self):
         return self._message
 
@@ -58,13 +59,20 @@ from firebirdsql.fbcore import ( __version__, apilevel, threadsafety,
 
 import firebirdsql.services
 
-def connect(dsn=None, user=None, password=None, host=None, 
-            database=None, charset=DEFAULT_CHARSET, port=3050):
-    return Connection(dsn=dsn, user=user, password=password, host=host, 
-                database=database, charset=charset, port=port)
+def connect(dsn=None, user=None, password=None, role=None, host=None, 
+            database=None, charset=DEFAULT_CHARSET, port=3050,
+            timeout=None, isolation_level=None, use_unicode=None):
+    return Connection(dsn=dsn, user=user, password=password,
+                role=role, host=host, 
+                database=database, charset=charset, port=port,
+                timeout=timeout, isolation_level=isolation_level,
+                use_unicode=use_unicode)
 
-def create_database(dsn=None, user=None, password=None, host=None,
-            database=None, charset=DEFAULT_CHARSET, port=3050, page_size=4096):
-    return Connection(dsn=dsn, user=user, password=password, host=host, 
+def create_database(dsn=None, user=None, password=None, host=None, role=None,
+            database=None, charset=DEFAULT_CHARSET, port=3050, page_size=4096,
+            timeout=None, isolation_level=None, use_unicode=None):
+    return Connection(dsn=dsn, user=user, password=password,
+                role=role, host=host, 
                 database=database, charset=charset, port=port, 
-                page_size=page_size)
+                page_size=page_size, timeout=timeout,
+                isolation_level=isolation_level, use_unicode=use_unicode)
